#ifndef NT2_INCLUDE_FUNCTIONS_MEANOF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MEANOF_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/meanof.hpp>

#endif
